// This simple list avoids a whole package
var main = {
Binary_Property : [
'Alphabetic',
'Any',
'ASCII',
'ASCII_Hex_Digit',
'Assigned',
'Bidi_Control',
'Bidi_Mirrored',
'Cased',
'Case_Ignorable',
'Changes_When_Casefolded',
'Changes_When_Casemapped',
'Changes_When_Lowercased',
'Changes_When_NFKC_Casefolded',
'Changes_When_Titlecased',
'Changes_When_Uppercased',
'Composition_Exclusion',
'Dash',
'Default_Ignorable_Code_Point',
'Deprecated',
'Diacritic',
'Emoji',
'Emoji_Component',
'Emoji_Modifier',
'Emoji_Presentation',    
'Expands_On_NFC',
'Expands_On_NFD',
'Expands_On_NFKC',
'Expands_On_NFKD',
'Extender',
'Full_Composition_Exclusion',
'Grapheme_Base',
'Grapheme_Extend',
'Grapheme_Link',
'Hex_Digit',
'Hyphen',
'ID_Continue',
'Ideographic',
'IDS_Binary_Operator',
'ID_Start',
'IDS_Trinary_Operator',
'Join_Control',
'Logical_Order_Exception',
'Lowercase',
'Math',
'Noncharacter_Code_Point',
'Other_Alphabetic',
'Other_Default_Ignorable_Code_Point',
'Other_Grapheme_Extend',
'Other_ID_Continue',
'Other_ID_Start',
'Other_Lowercase',
'Other_Math',
'Other_Uppercase',
'Pattern_Syntax',
'Pattern_White_Space',
'Prepended_Concatenation_Mark',
'Quotation_Mark',
'Radical',
'Regional_Indicator',
'Sentence_Terminal',
'Soft_Dotted',
'Terminal_Punctuation',
'Unified_Ideograph',
'Uppercase',
'Variation_Selector',
'White_Space',
'XID_Continue',
'XID_Start',
]
};
module.exports = main
